import react from 'react';
import { useState, useEffect } from 'react';
import { Map, Marker, ZoomControl } from 'pigeon-maps';
import GPXOverlay from './gpx-overlay';
import { registerPlugin } from '@capacitor/core';
import { BackgroundGeolocationPlugin } from '@capacitor-community/background-geolocation';
const BackgroundGeolocation = registerPlugin<BackgroundGeolocationPlugin>(
  'BackgroundGeolocation'
);

const LiveMap: react.FC = () => {
  const initialCenter: [number, number] = [43.57154, 3.94351];
  const initialZoom: number = 15;
  const [center, setCenter] = useState(initialCenter);
  const [position, setPosition] = useState(initialCenter);
  const [zoom, setZoom] = useState(initialZoom);

  const emptyTrack: any = {
    trkseg: [
      {
        trkpt: [
          {
            $: {
              lat: 43.57154,
              lon: 3.94351,
            },
          },
          {
            $: {
              lat: 43.56922,
              lon: 3.94228,
            },
          },
        ],
      },
    ],
  };

  let [track, setTrack] = useState(emptyTrack);

  /*
  useEffect(() => {
    console.log('com.dyomedea.dyomedea  LOG', ' - Adding the watcher');
    BackgroundGeolocation.addWatcher(
      {
        // If the "backgroundMessage" option is defined, the watcher will
        // provide location updates whether the app is in the background or the
        // foreground. If it is not defined, location updates are only
        // guaranteed in the foreground. This is true on both platforms.

        // On Android, a notification must be shown to continue receiving
        // location updates in the background. This option specifies the text of
        // that notification.
        backgroundMessage: 'Cancel to prevent battery drain.',

        // The title of the notification mentioned above. Defaults to "Using
        // your location".
        backgroundTitle: 'Tracking You.',

        // Whether permissions should be requested from the user automatically,
        // if they are not already granted. Defaults to "true".
        requestPermissions: true,

        // If "true", stale locations may be delivered while the device
        // obtains a GPS fix. You are responsible for checking the "time"
        // property. If "false", locations are guaranteed to be up to date.
        // Defaults to "false".
        stale: false,

        // The minimum number of metres between subsequent locations. Defaults
        // to 0.
        distanceFilter: 1,
      },
      function callback(location, error) {
        console.log('com.dyomedea.dyomedea  LOG', ' - Callback');
        if (error) {
          if (error.code === 'NOT_AUTHORIZED') {
            if (
              window.confirm(
                'This app needs your location, ' +
                  'but does not have permission.\n\n' +
                  'Open settings now?'
              )
            ) {
              // It can be useful to direct the user to their device's
              // settings when location permissions have been denied. The
              // plugin provides the 'openSettings' method to do exactly
              // this.
              BackgroundGeolocation.openSettings();
            }
          }
          return console.error(
            'com.dyomedea.dyomedea  LOG',
            ' - error: ',
            error
          );
        }
        console.log(location);
        if (location !== undefined) {
          setCenter([location.latitude, location.longitude]);
          setPosition([location.latitude, location.longitude]);
          track.geometry.coordinates.push([
            location.longitude,
            location.latitude,
          ]);
          setTrack(track);
        }

        return console.log(
          'com.dyomedea.dyomedea  LOG',
          ' - location: ',
          location
        );
      }
    )
      .then(function after_the_watcher_has_been_added(watcher_id) {
        // When a watcher is no longer needed, it should be removed by calling
        // 'removeWatcher' with an object containing its ID.
        console.log('com.dyomedea.dyomedea  LOG', ' - Watcher added');
        / *BackgroundGeolocation.removeWatcher({
        id: watcher_id,
      }); * /
      })
      .catch((reason) => {
        console.error('com.dyomedea.dyomedea  LOG', ' - reason: ', reason);
      });
  }, [track]);

  */
  return (
    <Map
      center={center}
      zoom={zoom}
      onBoundsChanged={({ center, zoom }) => {
        setCenter(center);
        setZoom(zoom);
      }}
      animate={true}
    >
      <ZoomControl />
      <Marker width={20} anchor={center} />
      <GPXOverlay
        mapState={undefined}
        latLngToPixel={undefined}
        track={track}
      />
    </Map>
  );
};

export default LiveMap;
